@@ -6,6 +6,23 @@
 """
 __docformat__ = "restructuredtext en"
 
+from yams.buildobjs import RelationDefinition
+
+try:
+    from cubes.card.schema import Card
+    from cubes.blog.schema import BlogEntry
+    from cubes.file.schema import File, Image
+    from cubes.link.schema import Link
+    from yams.reader import context
+    defined_types = context.defined
+except (ImportError, NameError):
+    # old-style yams schema will raise NameError on EntityType, RelationType, etc.
+    Card = import_erschema('Card')
+    BlogEntry = import_erschema('BlogEntry')
+    File = import_erschema('File')
+    Image = import_erschema('Image')
+    Link = import_erschema('Link')
+
 PERMISSIONS = {
         'read':   ('managers', 'users', 'guests',),
         'add':    ('managers', 'users',),
@@ -13,20 +30,11 @@ PERMISSIONS = {
         'update': ('managers', 'users', 'owners',),
         }
 
-Card = import_erschema('Card')
-Card.permissions = PERMISSIONS
-
-BlogEntry = import_erschema('BlogEntry')
-BlogEntry.permissions = PERMISSIONS
-
-File = import_erschema('File')
-File.permissions = PERMISSIONS
-
-Image = import_erschema('Image')
-Image.permissions = PERMISSIONS
-
-Link = import_erschema('Link')
-Link.permissions = PERMISSIONS
+Card.__permissions__ = PERMISSIONS
+BlogEntry.__permissions__ = PERMISSIONS
+File.__permissions__ = PERMISSIONS
+Image.__permissions__ = PERMISSIONS
+Link.__permissions__ = PERMISSIONS
 
 class interested_in(RelationDefinition):
     subject = 'CWUser'
@@ -37,8 +45,7 @@ BASETYPES = ('Card', 'BlogEntry', 'File', 'Image', 'Event', 'Link', 'Task', 'Boo
 if 'VersionedFile' in defined_types:
     BASETYPES += ('VersionedFile',)
 
-class see_also(RelationType):
-    symetric = True
+class see_also(RelationDefinition):
     subject = BASETYPES
     object = BASETYPES
 
