@@ -11,4 +11,4 @@ from cubicweb.selectors import implements
 from cubes.tag.views import TagsCloudBox
 
 TagsCloudBox.visible = True
-TagsCloudBox.__select__ &= implements('BlogEntry', 'Link', 'Card', 'File', 'Image')
+TagsCloudBox.__select__ = TagsCloudBox.__select__ & implements('BlogEntry', 'Link', 'Card', 'File', 'Image')
